@@ -7,7 +7,7 @@ use Moo;
 
 extends q(File::DataClass::ResultSource);
 
-has 'lang_dep' => is => 'ro', isa => HashRef, default => sub { {} };
+has 'language_dependent' => is => 'ro', isa => HashRef, default => sub { {} };
 
 1;
 
@@ -15,6 +15,8 @@ __END__
 
 =pod
 
+=encoding utf-8
+
 =head1 Name
 
 File::Gettext::ResultSource - Result source localisation
@@ -31,15 +33,17 @@ Defines these attributes
 
 =over 3
 
-=item B<lang_dep>
+=item C<language_dependent>
 
-Is a hash ref of language dependent attributes names. The values a just set
-to C<TRUE>
+Is a hash reference of language dependent attributes names. The values are just
+set to true
 
 =back
 
 =head1 Subroutines/Methods
 
+None
+
 =head1 Diagnostics
 
 None
@@ -68,7 +72,7 @@ Peter Flanigan, C<< <pjfl@cpan.org> >>
 
 =head1 License and Copyright
 
-Copyright (c) 2015 Peter Flanigan. All rights reserved
+Copyright (c) 2016 Peter Flanigan. All rights reserved
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>
