@@ -2,31 +2,36 @@ package File::Gettext::Schema;
 
 use namespace::autoclean;
 
-use File::DataClass::Constants qw( LANG TRUE );
-use File::DataClass::Types     qw( Directory Str Undef );
+use File::DataClass::Constants qw( FALSE LANG TRUE );
+use File::DataClass::Functions qw( is_hashref merge_attributes );
+use File::DataClass::Types     qw( Directory Str );
 use File::Gettext::Constants   qw( LOCALE_DIRS );
 use File::Gettext::ResultSource;
 use File::Gettext::Storage;
 use Scalar::Util               qw( blessed );
-use Type::Utils                qw( as coerce declare from enum via );
 use Moo;
 
 extends q(File::DataClass::Schema);
 
-my $LanguageType = declare as Str;
+has 'gettext_catagory' => is => 'ro', isa => Str, default => 'LC_MESSAGES';
 
-coerce $LanguageType, from Undef, via { LANG };
+has 'language'         => is => 'rw', isa => Str, default => LANG;
 
-has 'lang'      => is => 'rw', isa => $LanguageType, coerce => TRUE,
-   default      => LANG;
+has 'localedir'        => is => 'ro', isa => Directory, coerce => TRUE,
+   default             => sub { LOCALE_DIRS->[ 0 ] };
 
-has 'localedir' => is => 'ro', isa => Directory, coerce => TRUE,
-   default      => sub { LOCALE_DIRS->[ 0 ] };
+has '+result_source_class' => default => 'File::Gettext::ResultSource';
 
 around 'BUILDARGS' => sub {
-   my ($orig, $class, @args) = @_; my $attr = $orig->( $class, @args );
+   my ($orig, $self, @args) = @_; my $attr = $orig->( $self, @args );
 
-   $attr->{result_source_class} = 'File::Gettext::ResultSource';
+   # TODO: Deprecated
+   my $lang    = delete $attr->{lang}; $attr->{language} //= $lang;
+   my $builder = $attr->{builder} or return $attr;
+   my $config  = $builder->can( 'config' ) ? $builder->config : {};
+   my $keys    = [ qw( gettext_catagory language localedir ) ];
+
+   merge_attributes $attr, $config, $keys;
 
    return $attr;
 };
@@ -35,9 +40,9 @@ sub BUILD {
    my $self    = shift;
    my $storage = $self->storage;
    my $class   = 'File::Gettext::Storage';
-   my $attrs   = { schema => $self, storage => $storage };
+   my $attr    = { schema => $self, storage => $storage };
 
-   blessed $storage ne $class and $self->storage( $class->new( $attrs ) );
+   blessed $storage ne $class and $self->storage( $class->new( $attr ) );
 
    return;
 }
@@ -48,6 +53,8 @@ __END__
 
 =pod
 
+=encoding utf-8
+
 =head1 Name
 
 File::Gettext::Schema - Adds language support to the default schema
@@ -64,7 +71,12 @@ Defines these attributes
 
 =over 3
 
-=item C<lang>
+=item C<gettext_catagory>
+
+Subdirectory of C<localdir> that contains the F<mo> / F<po> files. Defaults
+to C<LC_MESSAGES>
+
+=item C<language>
 
 The two character language code, e.g. C<de>.
 
@@ -72,6 +84,10 @@ The two character language code, e.g. C<de>.
 
 Path to the subtree containing the MO/PO files
 
+=item C<result_source_class>
+
+Overrides the default
+
 =back
 
 =head1 Subroutines/Methods
@@ -87,12 +103,18 @@ L<File::Gettext::Storage> is created as a proxy for the storage class
 
 =head1 Diagnostics
 
+None
+
 =head1 Dependencies
 
 =over 3
 
+=item L<File::DataClass>
+
 =item L<Moo>
 
+=item L<Type::Tiny>
+
 =back
 
 =head1 Incompatibilities
@@ -115,7 +137,7 @@ Peter Flanigan, C<< <pjfl@cpan.org> >>
 
 =head1 License and Copyright
 
-Copyright (c) 2015 Peter Flanigan. All rights reserved
+Copyright (c) 2016 Peter Flanigan. All rights reserved
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>
